GENOCIDE
########

"By using the law to administer poison the king of the netherlands commits genocide" - :ref:`source <source>` - :ref:`admin <admin>`

ICC
===

| Information and Evidence Unit
| Office of the Prosecutor
| Post Office Box 19519
| 2500 CM The Hague
| The Netherlands

| emailed to otp.informationdesk@icc-cpi.int

Hello Office of the Prosecutor,

i write you in the context of communications and claims under art.15 of the Rome Statute. I want to inform the prosecutor that the king of the netherlands and his government are commiting 3 of the 5 crimes defined in the Rome Statute.
I know the statute only provides juridistion over genocide claims concerning nationalities or crimes based on etnicity. The crimes i talk about are on generic parts of the population like all elderly of all psychiatric patients.
The kingdom of the netherlands uses law to provide "care" with entails adminstering poison instead of non harmfull substances (what medicine should be). 

There is proof the medication used in forced treatements in the netherlands are poison.

1) haloperiodol (haldol) - https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142
2) clozapine (leponex) - https://echa.europa.eu/substance-information/-/substanceinfo/100.024.831
3) olanzapine (zyprexa) - https://echa.europa.eu/substance-information/-/substanceinfo/100.125.320
4) aripriprazole (abilify) https://echa.europa.eu/substance-information/-/substanceinfo/100.112.532

The dutch government has introduced three new forced care laws, the Wfz (wet forensische zorg) for criminals, the WvGGZ (Wet verplichte GGZ) for the disturbed and addicted and the Wzd (Wet zorg en dwang) for the handicapped.

Instead of groups with an nationaliteit or etnicity the laws targets the following victim groups in the netherlands:

1) verslaafden (addicts)
2) bejaarden (elderly)
3) ggz patienten (psychiatric patients)
4) criminelen (criminials)
5) gehandicapten (handicapped)
 
I informed the eerste kamer (who votes for the laws to be signed by the king) about the fact that these medicine as poison before the voted for these laws, i also informed the king about the fact that these medicine are poison before the law took effect.
Confirmation by the greffe and director of the kings cabinet are provided with this email (1).

With the laws that give instructions to "treat" certain groups in the population and the medicine used in that treatement turns out to be poison, the kingdom of the netherlands is, with the signature of the king, committing the following crimes mentioned in article 6:

a) Killing members of the group
b) Causing serious bodily or mental harm to members of the group
c) .
d) Imposing measures intended to prevent births within the group
e) .


Since the members of the chamber and the king were aware that these medicine are poison at the time they voted for this law and the day the Wfz law took effect (1-1-2019) i ask the prosecutor to prosecute 
the king and members of the chamber for three genocide crimes mentioned in article 6 on the note that this does not entail etnicity or nationality but on general groups in the population.

I hope you can stop the above mentioned crimes the king of the netherlands and his government are doing.

Bart Thate - bthate@dds.nl/thatebart@gmail.com

CHRONOLOGICAL
=============

| Information and Evidence Unit
| Office of the Prosecutor
| Post Office Box 19519
| 2500 CM The Hague
| The Netherlands 

Dear Mister Mark P. Dillon,

i received your writing to not to proceed with my request OTP-CR-117/19 on 20-05-2019.

i write you to ask you to reconsider now removed evidence has been restored online again.

In chronological order:

11-12-2017 I informed the chamber of the fact that the medicine used in treatements of psychiatric illnesses are poison
The proof exists of a url to the European Chemical Agency, showing that Haldol is a toxic substance (toxic if swallowed accompanied by a skull en bones).
his link worked a the time the chamber member were informed.

23-01-2018 The Chamber votes in favour of the Wet Forensische Zorg, Wet verplichte GGZ, Wet Zorg en Dwang knowing that the medicine used in these treatements are poison.

05-10-2018 I inform the King of the fact that these medicine are poison

01-01-2019 The Wet Forensische Zorg is activated

10-01-2019 I inform local authorities of the informednes of both the chamber member and the king.

21-01-2019 I inform the Office of the Prosecutor with proof that these medicine are poison and proof of the informedness of the King and the chamber members.

23-01-2019 I withdraw the request to arrest king and chamber member from the local authorities. They didn't react at all.

06-02-2019 The information on the ECHA website about Haldol being a poison is removed and a "nothing wrong with it" version is added

25-02-2019 After consideration i decided to formaly ask the king and chamber members to be prosecuted.

27-02-2019 I noticed that the site was updated and informed the Office of the Prosecutor about it.

20-05-2019 The Prosecutor informs me of his decision to not to proceed, mentioning the he could reconsider if new evidence arises.

25-06-2019 I talk to members of ECHA on twitter and got the link to the proof restored.

You can see the evidence that Haldol is a poison on https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142
You can see the email that informed the chamber of http://kamer.rtfd.io/
You can see the email that informed the king on http://koning.rtfd.io/

Knowing that the proof that Haldol is a poison was offline when you reached your conclusion to not to proceed, could you reconsider your conclusion now this proof is back online again ?

STATE OF AFFAIRS
================

“By adding Article 11 to the requirements, the prosecutor is actualy calling it a genocide and is missing the cooperation of the netherlands to arrest it’s own king and stop the kings genocide.” - https://genocide.readthedocs.io #ggz #gifpil

CONTACT
=======

i am reachable by email:

Bart Thate (bthate@dds.nl/thatebart@gmail.com)

EVIDENCE
########

poison
======

.. image:: cloza.png

letter
======

.. image:: informed.jpg
    :width: 100%

confirmed
=========

.. image:: opdehoogte.jpg
    :width: 100%

OTP1
====

.. image:: OTP1.png


OTP2
====

.. image:: OTP2.png


.. toctree::
    :glob:
    :hidden:

    *
